<?php

return [
    'Names' => [
        'aa' => '阿法文',
        'ab' => '阿布哈茲文',
        'ace' => '亞齊文',
        'ach' => '阿僑利文',
        'ada' => '阿當莫文',
        'ady' => '阿迪各文',
        'ae' => '阿維斯塔文',
        'aeb' => '突尼斯阿拉伯文',
        'af' => '南非荷蘭文',
        'afh' => '阿弗里希利文',
        'agq' => '亞罕文',
        'ain' => '阿伊努文',
        'ak' => '阿坎文',
        'akk' => '阿卡德文',
        'akz' => '阿拉巴馬文',
        'ale' => '阿留申文',
        'aln' => '蓋格阿爾巴尼亞文',
        'alt' => '南阿爾泰文',
        'am' => '阿姆哈拉文',
        'an' => '阿拉貢文',
        'ang' => '古英文',
        'ann' => '奧博洛語',
        'anp' => '昂加文',
        'ar' => '阿拉伯文',
        'arc' => '阿拉米文',
        'arn' => '馬普切文',
        'aro' => '阿拉奧納文',
        'arp' => '阿拉帕霍文',
        'arq' => '阿爾及利亞阿拉伯文',
        'ars' => '納吉迪阿拉伯文',
        'arw' => '阿拉瓦克文',
        'ary' => '摩洛哥阿拉伯文',
        'arz' => '埃及阿拉伯文',
        'as' => '阿薩姆文',
        'asa' => '阿蘇文',
        'ase' => '美國手語',
        'ast' => '阿斯圖里亞文',
        'atj' => '阿提卡梅克語',
        'av' => '阿瓦爾文',
        'avk' => '科塔瓦文',
        'awa' => '阿瓦文',
        'ay' => '艾馬拉文',
        'az' => '亞塞拜然文',
        'ba' => '巴什喀爾文',
        'bal' => '俾路支文',
        'ban' => '峇里文',
        'bar' => '巴伐利亞文',
        'bas' => '巴薩文',
        'bax' => '巴姆穆文',
        'bbc' => '巴塔克托巴文',
        'bbj' => '戈馬拉文',
        'be' => '白俄羅斯文',
        'bej' => '貝扎文',
        'bem' => '別姆巴文',
        'bew' => '貝塔維文',
        'bez' => '貝納文',
        'bfd' => '富特文',
        'bfq' => '巴達加文',
        'bg' => '保加利亞文',
        'bgn' => '西俾路支文',
        'bho' => '博傑普爾文',
        'bi' => '比斯拉馬文',
        'bik' => '比科爾文',
        'bin' => '比尼文',
        'bjn' => '班亞爾文',
        'bkm' => '康姆文',
        'bla' => '錫克錫卡文',
        'bm' => '班巴拉文',
        'bn' => '孟加拉文',
        'bo' => '藏文',
        'bpy' => '比什奴普萊利亞文',
        'bqi' => '巴赫蒂亞里文',
        'br' => '布列塔尼文',
        'bra' => '布拉杰文',
        'brh' => '布拉維文',
        'brx' => '博多文',
        'bs' => '波士尼亞文',
        'bss' => '阿庫色文',
        'bua' => '布里阿特文',
        'bug' => '布吉斯文',
        'bum' => '布魯文',
        'byn' => '比林文',
        'byv' => '梅敦巴文',
        'ca' => '加泰蘭文',
        'cad' => '卡多文',
        'car' => '加勒比文',
        'cay' => '卡尤加文',
        'cch' => '阿燦文',
        'ccp' => '查克馬文',
        'ce' => '車臣文',
        'ceb' => '宿霧文',
        'cgg' => '奇加文',
        'ch' => '查莫洛文',
        'chb' => '奇布查文',
        'chg' => '查加文',
        'chk' => '處奇斯文',
        'chm' => '馬里文',
        'chn' => '契奴克文',
        'cho' => '喬克托文',
        'chp' => '奇佩瓦揚文',
        'chr' => '柴羅基文',
        'chy' => '沙伊安文',
        'ckb' => '中庫德文',
        'clc' => '齊爾柯廷語',
        'co' => '科西嘉文',
        'cop' => '科普特文',
        'cps' => '卡皮茲文',
        'cr' => '克里文',
        'crg' => '米奇夫語',
        'crh' => '土耳其文（克里米亞半島）',
        'crj' => '東南克里語',
        'crk' => '平原克里語',
        'crl' => '北部東克里語',
        'crm' => '穆斯克里文',
        'crr' => '卡羅萊納阿爾岡昆語',
        'crs' => '塞席爾克里奧爾法文',
        'cs' => '捷克文',
        'csb' => '卡舒布文',
        'csw' => '沼澤克里語',
        'cu' => '宗教斯拉夫文',
        'cv' => '楚瓦什文',
        'cy' => '威爾斯文',
        'da' => '丹麥文',
        'dak' => '達科他文',
        'dar' => '達爾格瓦文',
        'dav' => '台塔文',
        'de' => '德文',
        'del' => '德拉瓦文',
        'den' => '斯拉夫',
        'dgr' => '多格里布文',
        'din' => '丁卡文',
        'dje' => '扎爾馬文',
        'doi' => '多格來文',
        'dsb' => '下索布文',
        'dtp' => '中部杜順文',
        'dua' => '杜亞拉文',
        'dum' => '中古荷蘭文',
        'dv' => '迪維西文',
        'dyo' => '朱拉文',
        'dyu' => '迪尤拉文',
        'dz' => '宗卡文',
        'dzg' => '達薩文',
        'ebu' => '恩布文',
        'ee' => '埃維文',
        'efi' => '埃菲克文',
        'egl' => '埃米利安文',
        'egy' => '古埃及文',
        'eka' => '艾卡朱克文',
        'el' => '希臘文',
        'elx' => '埃蘭文',
        'en' => '英文',
        'enm' => '中古英文',
        'eo' => '世界文',
        'es' => '西班牙文',
        'esu' => '中尤皮克文',
        'et' => '愛沙尼亞文',
        'eu' => '巴斯克文',
        'ewo' => '依汪都文',
        'ext' => '埃斯特雷馬杜拉文',
        'fa' => '波斯文',
        'fan' => '芳族文',
        'fat' => '芳蒂文',
        'ff' => '富拉文',
        'fi' => '芬蘭文',
        'fil' => '菲律賓文',
        'fit' => '托爾訥芬蘭文',
        'fj' => '斐濟文',
        'fo' => '法羅文',
        'fon' => '豐文',
        'fr' => '法文',
        'frc' => '卡真法文',
        'frm' => '中古法文',
        'fro' => '古法文',
        'frp' => '法蘭克-普羅旺斯文',
        'frr' => '北弗里西亞文',
        'frs' => '東弗里西亞文',
        'fur' => '弗留利文',
        'fy' => '西弗里西亞文',
        'ga' => '愛爾蘭文',
        'gaa' => '加族文',
        'gag' => '加告茲文',
        'gan' => '贛語',
        'gay' => '加約文',
        'gba' => '葛巴亞文',
        'gbz' => '索羅亞斯德教達里文',
        'gd' => '蘇格蘭蓋爾文',
        'gez' => '吉茲文',
        'gil' => '吉爾伯特群島文',
        'gl' => '加利西亞文',
        'glk' => '吉拉基文',
        'gmh' => '中古高地德文',
        'gn' => '瓜拉尼文',
        'goh' => '古高地德文',
        'gom' => '孔卡尼文',
        'gon' => '岡德文',
        'gor' => '科隆達羅文',
        'got' => '哥德文',
        'grb' => '格列博文',
        'grc' => '古希臘文',
        'gsw' => '德文（瑞士）',
        'gu' => '古吉拉特文',
        'guc' => '瓦尤文',
        'gur' => '弗拉弗拉文',
        'guz' => '古西文',
        'gv' => '曼島文',
        'gwi' => '圭契文',
        'ha' => '豪撒文',
        'hai' => '海達文',
        'hak' => '客家話',
        'haw' => '夏威夷文',
        'hax' => '南海達語',
        'he' => '希伯來文',
        'hi' => '印地文',
        'hif' => '斐濟印地文',
        'hil' => '希利蓋農文',
        'hit' => '赫梯文',
        'hmn' => '孟文',
        'ho' => '西里莫圖土文',
        'hr' => '克羅埃西亞文',
        'hsb' => '上索布文',
        'hsn' => '湘語',
        'ht' => '海地文',
        'hu' => '匈牙利文',
        'hup' => '胡帕文',
        'hur' => '哈爾魁梅林語',
        'hy' => '亞美尼亞文',
        'hz' => '赫雷羅文',
        'ia' => '國際文',
        'iba' => '伊班文',
        'ibb' => '伊比比奧文',
        'id' => '印尼文',
        'ie' => '國際文（E）',
        'ig' => '伊布文',
        'ii' => '四川彝文',
        'ik' => '依奴皮維克文',
        'ikt' => '西加拿大因紐特語',
        'ilo' => '伊洛闊文',
        'inh' => '印古什文',
        'io' => '伊多文',
        'is' => '冰島文',
        'it' => '義大利文',
        'iu' => '因紐特文',
        'izh' => '英格里亞文',
        'ja' => '日文',
        'jam' => '牙買加克里奧爾英文',
        'jbo' => '邏輯文',
        'jgo' => '恩格姆巴文',
        'jmc' => '馬恰美文',
        'jpr' => '猶太教-波斯文',
        'jrb' => '猶太阿拉伯文',
        'jut' => '日德蘭文',
        'jv' => '爪哇文',
        'ka' => '喬治亞文',
        'kaa' => '卡拉卡爾帕克文',
        'kab' => '卡比爾文',
        'kac' => '卡琴文',
        'kaj' => '卡捷文',
        'kam' => '卡姆巴文',
        'kaw' => '卡威文',
        'kbd' => '卡巴爾達文',
        'kbl' => '卡念布文',
        'kcg' => '卡塔布文',
        'kde' => '馬孔德文',
        'kea' => '卡布威爾第文',
        'ken' => '肯揚文',
        'kfo' => '科羅文',
        'kg' => '剛果文',
        'kgp' => '坎剛文',
        'kha' => '卡西文',
        'kho' => '和闐文',
        'khq' => '西桑海文',
        'khw' => '科瓦文',
        'ki' => '吉庫尤文',
        'kiu' => '北紮紮其文',
        'kj' => '廣亞馬文',
        'kk' => '哈薩克文',
        'kkj' => '卡庫文',
        'kl' => '格陵蘭文',
        'kln' => '卡倫金文',
        'km' => '高棉文',
        'kmb' => '金邦杜文',
        'kn' => '坎那達文',
        'ko' => '韓文',
        'koi' => '科米-彼爾米亞克文',
        'kok' => '貢根文',
        'kos' => '科斯雷恩文',
        'kpe' => '克佩列文',
        'kr' => '卡努里文',
        'krc' => '卡拉柴-包爾卡爾文',
        'kri' => '塞拉利昂克裏奧爾文',
        'krj' => '基那來阿文',
        'krl' => '卡累利阿文',
        'kru' => '庫魯科文',
        'ks' => '喀什米爾文',
        'ksb' => '尚巴拉文',
        'ksf' => '巴菲亞文',
        'ksh' => '科隆文',
        'ku' => '庫德文',
        'kum' => '庫密克文',
        'kut' => '庫特奈文',
        'kv' => '科米文',
        'kw' => '康瓦耳文',
        'kwk' => '誇誇嘉誇語',
        'ky' => '吉爾吉斯文',
        'la' => '拉丁文',
        'lad' => '拉迪諾文',
        'lag' => '朗吉文',
        'lah' => '拉亨達文',
        'lam' => '蘭巴文',
        'lb' => '盧森堡文',
        'lez' => '列茲干文',
        'lfn' => '新共同語言',
        'lg' => '干達文',
        'li' => '林堡文',
        'lij' => '利古里亞文',
        'lil' => '利洛威特文',
        'liv' => '利伏尼亞文',
        'lkt' => '拉科塔文',
        'lmo' => '倫巴底文',
        'ln' => '林加拉文',
        'lo' => '寮文',
        'lol' => '芒戈文',
        'lou' => '路易斯安那克里奧爾文',
        'loz' => '洛齊文',
        'lrc' => '北盧爾文',
        'lsm' => '薩米亞文',
        'lt' => '立陶宛文',
        'ltg' => '拉特加萊文',
        'lu' => '魯巴加丹加文',
        'lua' => '魯巴魯魯亞文',
        'lui' => '路易塞諾文',
        'lun' => '盧恩達文',
        'luo' => '盧奧文',
        'lus' => '米佐文',
        'luy' => '盧雅文',
        'lv' => '拉脫維亞文',
        'lzh' => '文言文',
        'lzz' => '拉茲文',
        'mad' => '馬都拉文',
        'maf' => '馬法文',
        'mag' => '馬加伊文',
        'mai' => '邁蒂利文',
        'mak' => '望加錫文',
        'man' => '曼丁哥文',
        'mas' => '馬賽文',
        'mde' => '馬巴文',
        'mdf' => '莫克沙文',
        'mdr' => '曼達文',
        'men' => '門德文',
        'mer' => '梅魯文',
        'mfe' => '克里奧文（模里西斯）',
        'mg' => '馬達加斯加文',
        'mga' => '中古愛爾蘭文',
        'mgh' => '馬夸文',
        'mgo' => '美塔文',
        'mh' => '馬紹爾文',
        'mi' => '毛利文',
        'mic' => '米克馬克文',
        'min' => '米南卡堡文',
        'mk' => '馬其頓文',
        'ml' => '馬來亞拉姆文',
        'mn' => '蒙古文',
        'mnc' => '滿族文',
        'mni' => '曼尼普爾文',
        'moe' => '因紐艾蒙語',
        'moh' => '莫霍克文',
        'mos' => '莫西文',
        'mr' => '馬拉地文',
        'mrj' => '西馬里文',
        'ms' => '馬來文',
        'mt' => '馬爾他文',
        'mua' => '蒙當文',
        'mus' => '克里克文',
        'mwl' => '米蘭德斯文',
        'mwr' => '馬瓦里文',
        'mwv' => '明打威文',
        'my' => '緬甸文',
        'mye' => '姆耶內文',
        'myv' => '厄爾茲亞文',
        'mzn' => '馬贊德蘭文',
        'na' => '諾魯文',
        'nan' => '閩南語',
        'nap' => '拿波里文',
        'naq' => '納馬文',
        'nb' => '巴克摩挪威文',
        'nd' => '北地畢列文',
        'nds' => '低地德文',
        'ne' => '尼泊爾文',
        'new' => '尼瓦爾文',
        'ng' => '恩東加文',
        'nia' => '尼亞斯文',
        'niu' => '紐埃文',
        'njo' => '阿沃那加文',
        'nl' => '荷蘭文',
        'nmg' => '夸西奧文',
        'nn' => '耐諾斯克挪威文',
        'nnh' => '恩甘澎文',
        'no' => '挪威文',
        'nog' => '諾蓋文',
        'non' => '古諾爾斯文',
        'nov' => '諾維亞文',
        'nqo' => '曼德文字 (N’Ko)',
        'nr' => '南地畢列文',
        'nso' => '北索托文',
        'nus' => '努埃爾文',
        'nv' => '納瓦荷文',
        'nwc' => '古尼瓦爾文',
        'ny' => '尼揚賈文',
        'nym' => '尼揚韋齊文',
        'nyn' => '尼揚科萊文',
        'nyo' => '尼奧囉文',
        'nzi' => '尼茲馬文',
        'oc' => '奧克西坦文',
        'oj' => '奧杰布瓦文',
        'ojb' => '西北奧吉布瓦語',
        'ojc' => '中央奧吉布瓦語',
        'ojs' => '奧吉克里語',
        'ojw' => '西奧吉布瓦語',
        'oka' => '奧卡諾根語',
        'om' => '奧羅莫文',
        'or' => '歐迪亞文',
        'os' => '奧塞提文',
        'osa' => '歐塞奇文',
        'ota' => '鄂圖曼土耳其文',
        'pa' => '旁遮普文',
        'pag' => '潘加辛文',
        'pal' => '巴列維文',
        'pam' => '潘帕嘉文',
        'pap' => '帕皮阿門托文',
        'pau' => '帛琉文',
        'pcd' => '庇卡底文',
        'pcm' => '奈及利亞皮欽文',
        'pdc' => '賓夕法尼亞德文',
        'pdt' => '門諾低地德文',
        'peo' => '古波斯文',
        'pfl' => '普法爾茨德文',
        'phn' => '腓尼基文',
        'pi' => '巴利文',
        'pis' => '皮金語',
        'pl' => '波蘭文',
        'pms' => '皮埃蒙特文',
        'pnt' => '旁狄希臘文',
        'pon' => '波那貝文',
        'pqm' => '馬里希特帕薩瑪奎迪文',
        'prg' => '普魯士文',
        'pro' => '古普羅旺斯文',
        'ps' => '普什圖文',
        'pt' => '葡萄牙文',
        'qu' => '蓋楚瓦文',
        'quc' => '基切文',
        'qug' => '欽博拉索海蘭蓋丘亞文',
        'raj' => '拉賈斯坦諸文',
        'rap' => '復活島文',
        'rar' => '拉羅通加文',
        'rgn' => '羅馬格諾里文',
        'rhg' => '羅興亞文',
        'rif' => '里菲亞諾文',
        'rm' => '羅曼斯文',
        'rn' => '隆迪文',
        'ro' => '羅馬尼亞文',
        'rof' => '蘭博文',
        'rom' => '吉普賽文',
        'rtm' => '羅圖馬島文',
        'ru' => '俄文',
        'rue' => '盧森尼亞文',
        'rug' => '羅維阿納文',
        'rup' => '羅馬尼亞語系',
        'rw' => '盧安達文',
        'rwk' => '羅瓦文',
        'sa' => '梵文',
        'sad' => '桑達韋文',
        'sah' => '雅庫特文',
        'sam' => '薩瑪利亞阿拉姆文',
        'saq' => '薩布魯文',
        'sas' => '撒撒克文',
        'sat' => '桑塔利文',
        'saz' => '索拉什特拉文',
        'sba' => '甘拜文',
        'sbp' => '桑古文',
        'sc' => '撒丁文',
        'scn' => '西西里文',
        'sco' => '蘇格蘭文',
        'sd' => '信德文',
        'sdc' => '薩丁尼亞-薩薩里文',
        'sdh' => '南庫德文',
        'se' => '北薩米文',
        'see' => '塞訥卡文',
        'seh' => '賽納文',
        'sei' => '瑟里文',
        'sel' => '塞爾庫普文',
        'ses' => '東桑海文',
        'sg' => '桑戈文',
        'sga' => '古愛爾蘭文',
        'sgs' => '薩莫吉希亞文',
        'sh' => '塞爾維亞克羅埃西亞文',
        'shi' => '希爾哈文',
        'shn' => '撣文',
        'shu' => '阿拉伯文（查德）',
        'si' => '僧伽羅文',
        'sid' => '希達摩文',
        'sk' => '斯洛伐克文',
        'sl' => '斯洛維尼亞文',
        'slh' => '南盧紹錫德語',
        'sli' => '下西利西亞文',
        'sly' => '塞拉亞文',
        'sm' => '薩摩亞文',
        'sma' => '南薩米文',
        'smj' => '魯勒薩米文',
        'smn' => '伊納里薩米文',
        'sms' => '斯科特薩米文',
        'sn' => '紹納文',
        'snk' => '索尼基文',
        'so' => '索馬利文',
        'sog' => '索格底亞納文',
        'sq' => '阿爾巴尼亞文',
        'sr' => '塞爾維亞文',
        'srn' => '蘇拉南東墎文',
        'srr' => '塞雷爾文',
        'ss' => '斯瓦特文',
        'ssy' => '薩霍文',
        'st' => '塞索托文',
        'stq' => '沙特菲士蘭文',
        'str' => '海峽薩利希語',
        'su' => '巽他文',
        'suk' => '蘇庫馬文',
        'sus' => '蘇蘇文',
        'sux' => '蘇美文',
        'sv' => '瑞典文',
        'sw' => '史瓦希里文',
        'swb' => '葛摩文',
        'syc' => '古敘利亞文',
        'syr' => '敘利亞文',
        'szl' => '西利西亞文',
        'ta' => '坦米爾文',
        'tce' => '南塔穹語',
        'tcy' => '圖盧文',
        'te' => '泰盧固文',
        'tem' => '提姆文',
        'teo' => '特索文',
        'ter' => '泰雷諾文',
        'tet' => '泰頓文',
        'tg' => '塔吉克文',
        'tgx' => '塔吉什語',
        'th' => '泰文',
        'tht' => '塔爾坦語',
        'ti' => '提格利尼亞文',
        'tig' => '蒂格雷文',
        'tiv' => '提夫文',
        'tk' => '土庫曼文',
        'tkl' => '托克勞文',
        'tkr' => '查庫爾文',
        'tl' => '塔加路族文',
        'tlh' => '克林貢文',
        'tli' => '特林基特文',
        'tly' => '塔里什文',
        'tmh' => '塔馬奇克文',
        'tn' => '塞茲瓦納文',
        'to' => '東加文',
        'tog' => '東加文（尼亞薩）',
        'tok' => '道本語',
        'tpi' => '托比辛文',
        'tr' => '土耳其文',
        'tru' => '圖羅尤文',
        'trv' => '太魯閣文',
        'ts' => '特松加文',
        'tsd' => '特薩克尼恩文',
        'tsi' => '欽西安文',
        'tt' => '韃靼文',
        'ttm' => '北塔穹語',
        'ttt' => '穆斯林塔特文',
        'tum' => '圖姆布卡文',
        'tvl' => '吐瓦魯文',
        'tw' => '特威文',
        'twq' => '北桑海文',
        'ty' => '大溪地文',
        'tyv' => '圖瓦文',
        'tzm' => '中阿特拉斯塔馬塞特文',
        'udm' => '烏德穆爾特文',
        'ug' => '維吾爾文',
        'uga' => '烏加列文',
        'uk' => '烏克蘭文',
        'umb' => '姆本杜文',
        'ur' => '烏都文',
        'uz' => '烏茲別克文',
        'vai' => '瓦伊文',
        've' => '溫達文',
        'vec' => '威尼斯文',
        'vep' => '維普森文',
        'vi' => '越南文',
        'vls' => '西佛蘭德文',
        'vmf' => '美茵-法蘭克尼亞文',
        'vo' => '沃拉普克文',
        'vot' => '沃提克文',
        'vro' => '佛羅文',
        'vun' => '溫舊文',
        'wa' => '瓦隆文',
        'wae' => '瓦爾瑟文',
        'wal' => '瓦拉莫文',
        'war' => '瓦瑞文',
        'was' => '瓦紹文',
        'wbp' => '沃皮瑞文',
        'wo' => '沃洛夫文',
        'wuu' => '吳語',
        'xal' => '卡爾梅克文',
        'xh' => '科薩文',
        'xmf' => '明格列爾文',
        'xog' => '索加文',
        'yao' => '瑤文',
        'yap' => '雅浦文',
        'yav' => '洋卞文',
        'ybb' => '耶姆巴文',
        'yi' => '意第緒文',
        'yo' => '約魯巴文',
        'yrl' => '奈恩加圖文',
        'yue' => '粵語',
        'za' => '壯文',
        'zap' => '薩波特克文',
        'zbl' => '布列斯符號',
        'zea' => '西蘭文',
        'zen' => '澤納加文',
        'zgh' => '標準摩洛哥塔馬塞特文',
        'zh' => '中文',
        'zu' => '祖魯文',
        'zun' => '祖尼文',
        'zza' => '扎扎文',
    ],
    'LocalizedNames' => [
        'ar_001' => '現代標準阿拉伯文',
        'de_CH' => '高地德文（瑞士）',
        'hi_Latn' => '印地語（拉丁文）',
        'nds_NL' => '低地薩克遜文',
        'nl_BE' => '佛蘭芒文',
        'ro_MD' => '摩爾多瓦文',
        'sw_CD' => '史瓦希里文（剛果）',
        'zh_Hans' => '簡體中文',
        'zh_Hant' => '繁體中文',
    ],
];
